@@ -236,8 +236,8 @@ class Model(DatetimeMixin, Model):
     在使用的时候，需要同时继承 ``Model`` 和 ``Model.Meta`` 。
     """
 
-    class Meta:
-        abstract = True
+    class BaseMeta:
+        abstract = False
         verbose_name = '未定义模型名称'
 
         # noinspection PyMethodParameters
@@ -245,6 +245,9 @@ class Model(DatetimeMixin, Model):
         def verbose_name_plural(cls):
             return cls.verbose_name
 
+    class Meta(BaseMeta):
+        abstract = True
+
 
 class _MappableIntegerChoiceMeta(django.db.models.enums.ChoicesMeta):
     # noinspection PyMethodParameters
